pub async fn read_location(conn: &Connection, endpoint: u16) -> Result<String>Expand description
Read Location attribute from cluster Bridged Device Basic Information.
pub async fn read_location(conn: &Connection, endpoint: u16) -> Result<String>Read Location attribute from cluster Bridged Device Basic Information.