pub async fn read_reachable(conn: &Connection, endpoint: u16) -> Result<bool>Expand description
Read Reachable attribute from cluster Bridged Device Basic Information.
pub async fn read_reachable(conn: &Connection, endpoint: u16) -> Result<bool>Read Reachable attribute from cluster Bridged Device Basic Information.